# Reference

<!-- THIS REFERENCE HAS BEEN GENERATED AUTOMATICALLY.
DO NOT EDIT, UPDATE .vuepress/_reference FILES INSTEAD AND RUN autogen.py -->

This reference documents the public stable API of machinable.

::: tip
For a high-level introduction, read the [user guide](../guide/README.md).
:::

Undocumented methods should be considered internal and are subject to change at any time.